@@ -54,13 +54,13 @@ catArgGroup.add_argument(
     help="IBM entitlement key"
 )
 
-# Aibroker Basic Configuration
+# AI Service Basic Configuration
 # -----------------------------------------------------------------------------
-masArgGroup = aiServiceinstallArgParser.add_argument_group("Aibroker Basic Configuration")
+masArgGroup = aiServiceinstallArgParser.add_argument_group("AI Service Basic Configuration")
 masArgGroup.add_argument(
     "-i", "--aiservice-instance-id",
     required=False,
-    help="Aibroker Instance ID"
+    help="AI Service Instance ID"
 )
 
 # MAS Advanced Configuration
@@ -171,21 +171,22 @@ masAppsArgGroup.add_argument(
     help="Subscription channel for Maximo AI Service"
 )
 
-# AI Service
+# ODH
 # -----------------------------------------------------------------------------
-aiServiceArgGroup = aiServiceinstallArgParser.add_argument_group("Maximo AI Service")
+odhArgGroup = aiServiceinstallArgParser.add_argument_group("Opendatahub")
+
+odhArgGroup.add_argument(
+    "--odh-model-deployment-type",
+    dest="aiservice_odh_model_deployment_type",
+    required=False,
+    default="raw",
+    help="Model deployment type for ODH"
+)
 
 # S3 - General
 # -----------------------------------------------------------------------------
 s3ArgGroup = aiServiceinstallArgParser.add_argument_group("S3 Storage")
 
-# s3ArgGroup.add_argument(
-#     "--s3-provider",
-#     dest="aiservice_s3_provider",
-#     required=False,
-#     help="S3 storage provider type (e.g., minio, aws)"
-# )
-
 # S3 - Minio
 # -----------------------------------------------------------------------------
 s3ArgGroup.add_argument(
@@ -304,23 +305,26 @@ watsonxArgGroup.add_argument(
 
 # AI Service
 # -----------------------------------------------------------------------------
+aiServiceArgGroup = aiServiceinstallArgParser.add_argument_group("Maximo AI Service")
+
 aiServiceArgGroup.add_argument(
     "--tenant-entitlement-type",
     dest="tenant_entitlement_type",
     required=False,
-    help="Type of aibroker tenant"
+    default="standard",
+    help="Entitlement type for AI Service tenant"
 )
 aiServiceArgGroup.add_argument(
     "--tenant-entitlement-start-date",
     dest="tenant_entitlement_start_date",
     required=False,
-    help="Start date for Aibroker tenant"
+    help="Start date for AI Service tenant"
 )
 aiServiceArgGroup.add_argument(
     "--tenant-entitlement-end-date",
     dest="tenant_entitlement_end_date",
     required=False,
-    help="End date for Aibroker tenant"
+    help="End date for AI Service tenant"
 )
 aiServiceArgGroup.add_argument(
     "--rsl-url",
