@@ -163,7 +163,6 @@ class installArgBuilderMixin():
             command += f"  --monitor-channel \"{self.getParam('mas_app_channel_monitor')}\"{newline}"
         if self.installManage:
             command += f"  --manage-channel \"{self.getParam('mas_app_channel_manage')}\"{newline}"
-            command += f"  --is-full-manage \"{self.getParam('is_full_manage')}\"{newline}"
         if self.installOptimizer:
             command += f"  --optimizer-channel \"{self.getParam('mas_app_channel_optimizer')}\""
             command += f" --optimizer-plan \"{self.getParam('mas_app_plan_optimizer')}\"{newline}"
@@ -237,6 +236,9 @@ class installArgBuilderMixin():
             if self.getParam('mas_appws_bindings_health_wsl_flag') == "true":
                 command += f"  --manage-health-wsl{newline}"
 
+            if self.getParam('mas_appws_upgrade_type') == "true":
+                command += f"  --manage-upgrade-type \"{self.getParam('mas_appws_upgrade_type')}\"{newline}"
+
         # Facilities Advanced Settings
         # -----------------------------------------------------------------------------
         # TODO: Fix type for storage sizes and max conn pool size
